@@ -1,8 +1,7 @@
 from neotermcolor import cprint
 from datetime import *
-from os import path
-import sys
-__version__ = "1.1.3"
+import sys, os
+__version__ = "1.2.0"
 __author__ = 'Logan Houston'
 class Logger:
     # flags in order of bit placement, LTR
@@ -22,7 +21,7 @@ class Logger:
     flags = 0
 
     def __init__(self, use_256 = False, use_channels = False, use_whitespace =
-                False, use_file = False, file_dir = "./logs/", file_type = ".log", file_name = "%Y-%m-%d %H-%M-%S", flags = 0):
+                False, use_verbose = False, use_file = False, file_dir = "./logs/", file_type = ".log", file_name = "%Y-%m-%d %H-%M-%S", flags = 0):
                 # Decent logging system that has a few options
                 # If you experience compatibility issues please try toggling use_256 either via flags or args
                 #
@@ -30,11 +29,12 @@ class Logger:
                 # use_256 -- use 256 color palette instead of 16
                 # use_channels -- use different output channels
                 # use_whitespace -- use whitespace between log parameters
+                # use_verbose -- print extra information, useful for debugging
                 # use_file -- use output file ('file_*' required if use_file == True)
                 #   file_dir -- path to log folder (default: './logs/')
                 #   file_type -- type of log file, doesnt change contents (default: '.log')
                 #   file_name -- name of log file, passed through datetime.datetime.now().strftime() (default: '%Y-%m-%d %H-%M-%S')
-                # flags -- shorter way to set options, reverse order of parameters (default: 0)
+                # flags -- shorter way to set options, reverse order of "use_*" parameters (default: 0)
         if flags:
             self.flags = flags
             if flags & 1 == 1: self.use_256 = True
@@ -49,16 +49,19 @@ class Logger:
             self.use_256 = use_256
             self.use_channels = use_channels
             self.use_whitespace = use_whitespace
+            self.use_verbose = use_verbose
             self.use_file = use_file
             self.flags = self._generate_flags()
         if self.use_file:
-            self.log_path = path.abspath(file_dir) + datetime.now().strftime(file_name) + file_type
-            self.log_file = open(self.log_path, "a+")
-            self.file_name = file_name
+            self.log_path = os.path.abspath(file_dir)
+            if not os.path.isdir(self.log_path):
+                print("Log dir doesnt exist, creating one...")
+                os.mkdir(self.log_path)
+            self.file_name = datetime.now().strftime(file_name) + file_type
+            self.log_file = self.log_path + "/" + self.file_name
 
     def __del__(self):
-        if not self.log_file.closed:
-            self.log_file.close()
+
 
     def log(self, message: str, lvl: str = "LOG", timestamp: datetime = None, nt_attrs =
             [], prefix = "", prefixes = [], channel = DEFAULT_CHANNEL):
@@ -72,10 +75,13 @@ class Logger:
             print("Logger print args:", f"{nt_attrs=}", f"{prefix=}", f"{channel=}",
                    f"color={self.levels[lvl.upper()][int(self.use_256)]}")
         cprint(f"[{lvl}]"+message, self.levels[lvl.upper()][int(self.use_256)], attrs=nt_attrs)
-        if self.use_file: self.log_file.write(f"[{lvl}]"+message)
+        if self.use_file:
+            with open(self.log_file) as lf:
+                lf.write(f"[{lvl}]"+message+os.linesep)
+                lf.close()
 
     def err(self, message: str, timestamp: datetime = None, nt_attrs =
-            [], prefix = "", prefixes = [], channel = DEFAULT_CHANNEL): # Shorthand function for predefined logging levels
+            [], prefix = "", prefixes = [], channel = DEFAULT_CHANNEL, **kwargs): # Shorthand function for predefined logging levels
             self.log(message, "ERR", timestamp, nt_attrs, prefix, prefixes, channel)
 
     def warn(self, message: str, timestamp: datetime = None, nt_attrs =
@@ -123,4 +129,3 @@ class Logger:
         return color_tuple
 
 def _bis(boolean) -> str: return str(int(boolean))
-l = Logger(use_whitespace=True, use_channels=True)
